Crate librsvg_rebind

Crate librsvg_rebind 

Rust librsvg bindings

This package contains safe Rust bindings for the librsvg C library.

Since librsvg is written in Rust, the native rsvg crate is available to use the same features. One of the main purposes of librsvg-rebind is to reduce the binary sice.

To use this package, the librsvg-2 library has to be available on the system. If you use the native rsvg crate, this is not required.

Example

use librsvg_rebind::prelude::*;

let handle = librsvg_rebind::Handle::from_file("../../rsvg/example.svg")
    .unwrap()
    .unwrap();

let (width, height) = handle.intrinsic_size_in_pixels().unwrap();

let surface =
    cairo::ImageSurface::create(cairo::Format::ARgb32, width as i32, height as i32).unwrap();
let context = cairo::Context::new(&surface).unwrap();

let viewport = librsvg_rebind::Rectangle::new(0., 0., height, width);

handle.render_document(&context, &viewport).unwrap();

let mut output_file = std::fs::File::create("/dev/null").unwrap();
surface.write_to_png(&mut output_file).unwrap();

Re-exports

pub use ffi;
pub use gio;
pub use glib;

Modules

prelude

Structs

Handle
GLib type: GObject with reference counted clone semantics.
HandleFlags
Length
GLib type: Inline allocated boxed type with stack copy semantics.
Rectangle
GLib type: Inline allocated boxed type with stack copy semantics.

Enums

Error
Unit